@@ -109,11 +109,7 @@ bootstrapCrossValidation <- function(object,
         try2predict <- try(pred.b <- do.call(predictHandlerFun,c(list(object=fit.b,newdata=val.b,times=times,cause=cause,train.data=train.b),extraArgs)))
       }
       else{
-        try2predict <- try(pred.b <- do.call(predictHandlerFun,
-                                             c(list(object=fit.b,
-                                                    newdata=val.b,
-                                                    times=times,
-                                                    train.data=train.b),extraArgs)))
+        try2predict <- try(pred.b <- do.call(predictHandlerFun,c(list(object=fit.b,newdata=val.b,times=times,train.data=train.b),extraArgs)))
       }
       if (inherits(try2predict,"try-error")==TRUE){
         if (verbose==TRUE) warning(paste("During bootstrapping: prediction for model ",class(fit.b)," failed in step ",b),immediate.=TRUE)
